# p1 [![Português](images/BR.png)](README.pt-BR.md) [![English](images/US.png)](README.md)

p1 é um pacote com ferramentas para o apoio às disciplinas de
Programação 1 da Computação@UFCG.

## Instalação

```
pip3 install --user p1
```

## Inclui...

A ideia é que ao instalar o `p1ufcg`, vários pacotes e módulos
que são úteis na disciplina serão instalados em conjunto. Segue a
lista do que é instalado na atual versão.

### packages

- [tst](https://github.com/daltonserey/tst)
- [pytest](https://docs.pytest.org)

### módulos

- [Array](array.md)
